@@ -3,6 +3,8 @@ import shutil, os, glob
 from datetime import datetime, timedelta
 import calendar
 import pickle
+
+import slider
 from jinjafy import jinjafy_comment
 from jinjafy import jinjafy_template
 from coursebox.core.info_paths import get_paths
@@ -12,7 +14,8 @@ from slider.slider import set_svg_background_images
 from coursebox.book.exam_includer import HOMEWORK_PROBLEMS
 from coursebox.core.info import class_information
 from coursebox.material.lecture_questions import lecture_question_compiler
-from thtools import latexmk
+from slider import latexmk
+import coursebox
 
 def get_feedback_groups():
     paths = get_paths()
@@ -44,7 +47,7 @@ def get_feedback_groups():
     reduced_groups = [rg for rg in reduced_groups if len(rg)>0]
     # groups are now partitioned.
     if len(remaining_lectures) > 0:
-        fbgs = thtools.thtools_base.partition_list(reduced_groups, len(remaining_lectures))
+        fbgs = coursebox.thtools_base.partition_list(reduced_groups, len(remaining_lectures))
         for gg in fbgs:
             for g in gg:
                 already_used = already_used + g
@@ -154,7 +157,7 @@ def make_lectures(week=None, mode=0, gather_pdf_out=True, gather_sixup=True, mak
         if make_quizzes:
             lecture_question_compiler(paths, info, lecture_texfile)
 
-        pdf_out = thtools.latexmk(lecture_texfile, Linux=Linux)
+        pdf_out = slider.latexmk(lecture_texfile, Linux=Linux)
         all_pdfs.append( (w,pdf_out))
 
     handle_pdf_collection(paths, all_pdfs, gather_pdf_out=gather_pdf_out, gather_sixup=gather_sixup, odir=odex)
@@ -180,7 +183,7 @@ def handle_pdf_collection(paths, all_pdfs, gather_pdf_out, gather_sixup, odir):
                 tv['sixup'] = sixup
                 tex_out_sixup = tmp_dir + "/Lecture_%i%s.tex" % (week, sixup_str)
                 jinjafy_comment(data=tv, file_in=collect_template, file_out=tex_out_sixup, jinja_tag=None)
-                dpdf = tmp_dir + "/" + thtools.latexmk(tex_out_sixup, shell=False, cleanup=True)
+                dpdf = tmp_dir + "/" + slider.latexmk(tex_out_sixup, shell=False, cleanup=True)
             else:
                 dpdf = tv['pdffiles'][0]
 
@@ -212,16 +215,16 @@ def compile_simple_files(paths, info, template_file_list, verbose=False):
             file = file.replace("_template.tex", ".tex")
         tex_out = paths['shared_latex_compilation_dir'] + "/" + file
         jinjafy_template(data=d2, file_in=fname, file_out=tex_out, filters=get_filters(), template_searchpath=paths['instructor'])
-        thtools.latexmk(tex_out, pdf_out= paths['pdf_out'] + "/" + os.path.basename(tex_out)[:-4]+".pdf")
+        latexmk(tex_out, pdf_out= paths['pdf_out'] + "/" + os.path.basename(tex_out)[:-4]+".pdf")
 
 def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compile_templates=True):
     '''
     Copy shared files into lecture directories
     '''
     cache_base = output_dir
-    from thtools.cache import cache_contains_file, cache_update_file
-    from thtools.slider.convert import svg2pdf, pdfcrop
-    from thtools.slider import convert
+    from jinjafy.cache import cache_contains_file, cache_update_file
+    from slider.convert import svg2pdf, pdfcrop
+    from slider import convert
 
     def rec_fix_shared(shared_base, output_dir):
         if dosvg:
